==> freeciv-1.13.0.tar.bz2: freeciv-1.13.0/client/gui-gtk-2.0/inputdlg.c <==
/********************************************************************** 
 Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
***********************************************************************/
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdio.h>

#include <gtk/gtk.h>  

#include "fcintl.h"

#include "gui_main.h"
#include "gui_stuff.h"

#include "inputdlg.h"

/****************************************************************
...
*****************************************************************/
const char *input_dialog_get_input(GtkWidget *button)
{
  const char *dp;
  GtkWidget *winput;
      
  winput=gtk_object_get_data(GTK_OBJECT(button->parent->parent->parent),
	"iinput");
  
  dp=gtk_entry_get_text(GTK_ENTRY(winput));
 
  return dp;
}


/****************************************************************
...
*****************************************************************/
void input_dialog_destroy(GtkWidget *button)
{
  GtkWidget *parent;

  parent=gtk_object_get_data(GTK_OBJECT(button->parent->parent->parent),
	"parent");

  gtk_widget_set_sensitive(parent, TRUE);

  gtk_widget_destroy(button->parent->parent->parent);
}


/****************************************************************
...
*****************************************************************/
static gint input_dialog_del_callback(GtkWidget *w, GdkEvent *ev, gpointer data)
{
  gtk_widget_set_sensitive((GtkWidget *)data, TRUE);
  return FALSE;
}

/****************************************************************
...
*****************************************************************/
GtkWidget *input_dialog_create(GtkWidget *parent, char *dialogname, 
			   char *text, char *postinputtest,
			   void *ok_callback, gpointer ok_cli_data, 
			   void *cancel_callback, gpointer cancel_cli_data)
{
  GtkWidget *shell, *label, *input, *ok, *cancel;
  
  gtk_widget_set_sensitive(parent, FALSE);
  
  shell=gtk_dialog_new();
  gtk_signal_connect(GTK_OBJECT(shell),"delete_event",
	GTK_SIGNAL_FUNC(input_dialog_del_callback), parent);

  gtk_window_set_title(GTK_WINDOW(shell), dialogname);
  
  gtk_container_border_width(GTK_CONTAINER(GTK_DIALOG(shell)->vbox), 5);

  label=gtk_frame_new(text);
  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(shell)->vbox), label, TRUE, TRUE, 0);

  input=gtk_entry_new();
  gtk_container_add(GTK_CONTAINER(label), input);
  gtk_entry_set_text(GTK_ENTRY(input),postinputtest);
  
  gtk_signal_connect(GTK_OBJECT(input), "activate",
	GTK_SIGNAL_FUNC(ok_callback), ok_cli_data);

  ok=gtk_button_new_with_label(_("Ok"));
  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(shell)->action_area),
	ok, TRUE, TRUE, 0);
  gtk_signal_connect(GTK_OBJECT(ok), "clicked",
	GTK_SIGNAL_FUNC(ok_callback), ok_cli_data);

  cancel=gtk_button_new_with_label(_("Cancel"));
  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(shell)->action_area),
	cancel, TRUE, TRUE, 0);
  gtk_signal_connect(GTK_OBJECT(cancel), "clicked",
	GTK_SIGNAL_FUNC(cancel_callback), cancel_cli_data);

  gtk_widget_grab_focus(input);
    
  gtk_set_relative_position(parent, shell, 10, 10);

  gtk_object_set_data(GTK_OBJECT(shell), "iinput",input);
  gtk_object_set_data(GTK_OBJECT(shell), "parent",parent);

  gtk_widget_show_all(GTK_DIALOG(shell)->vbox);
  gtk_widget_show_all(GTK_DIALOG(shell)->action_area);
  gtk_widget_show(shell);
  
  return shell;
}

==> freeciv-1.14.1.tar.bz2: freeciv-1.14.1/client/gui-gtk-2.0/inputdlg.c <==
/********************************************************************** 
 Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
***********************************************************************/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdio.h>

#include <gtk/gtk.h>  

#include "fcintl.h"

#include "gui_main.h"
#include "gui_stuff.h"

#include "inputdlg.h"

/****************************************************************
...
*****************************************************************/
const char *input_dialog_get_input(GtkWidget *button)
{
  const char *dp;
  GtkWidget *winput;
      
  winput=g_object_get_data(G_OBJECT(button->parent->parent->parent),
	"iinput");
  
  dp=gtk_entry_get_text(GTK_ENTRY(winput));
 
  return dp;
}


/****************************************************************
...
*****************************************************************/
void input_dialog_destroy(GtkWidget *button)
{
  gtk_widget_destroy(button->parent->parent->parent);
}


/****************************************************************
...
*****************************************************************/
GtkWidget *input_dialog_create(GtkWindow *parent, char *dialogname, 
			   char *text, char *postinputtest,
			   GCallback ok_callback, gpointer ok_cli_data, 
			   GCallback cancel_callback, gpointer cancel_cli_data)
{
  GtkWidget *shell, *label, *input, *ok, *cancel;
  
  shell = gtk_dialog_new_with_buttons(dialogname,
        parent,
        GTK_DIALOG_DESTROY_WITH_PARENT,
        NULL);
  gtk_window_set_position(GTK_WINDOW(shell), GTK_WIN_POS_CENTER_ON_PARENT);

  label = gtk_frame_new(text);
  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(shell)->vbox), label, TRUE, TRUE, 0);

  input = gtk_entry_new();
  gtk_container_add(GTK_CONTAINER(label), input);
  gtk_entry_set_text(GTK_ENTRY(input), postinputtest);

  g_signal_connect(input, "activate", ok_callback, ok_cli_data);

  cancel = gtk_dialog_add_button(GTK_DIALOG(shell), GTK_STOCK_CANCEL,
    GTK_RESPONSE_CANCEL);
  ok = gtk_dialog_add_button(GTK_DIALOG(shell), GTK_STOCK_OK,
    GTK_RESPONSE_OK);

  g_signal_connect(ok, "clicked", ok_callback, ok_cli_data);
  g_signal_connect(cancel, "clicked", cancel_callback, cancel_cli_data);

  gtk_widget_grab_focus(input);

  g_object_set_data(G_OBJECT(shell), "iinput", input);

  gtk_widget_show_all(GTK_DIALOG(shell)->vbox);
  gtk_widget_show_all(GTK_DIALOG(shell)->action_area);
  gtk_window_present(GTK_WINDOW(shell));

  return shell;
}
